@@ -21,9 +21,13 @@ from os import listdir
 from os import path
 
 from tuskar.storage.exceptions import UnknownName
+from tuskar.storage.stores import MasterSeedStore
 from tuskar.storage.stores import TemplateStore
 
 
+MASTER_SEED_NAME = '_master_seed'
+
+
 def _list_roles(directory):
     """Scan a directory and yield a tuple for all the roles containing the
     role name and the full path to the role.
@@ -43,7 +47,7 @@ def _list_roles(directory):
         yield role_name, path.join(directory, filename)
 
 
-def _read_role(role_path):
+def _load_file(role_path):
 
     with open(role_path) as role_file:
         return role_file.read()
@@ -65,7 +69,7 @@ def _create_or_update(name, contents, store=None):
         return True, store.create(name, contents)
 
 
-def load_roles(directory, dry_run=False):
+def load_roles(directory, seed_file=None, dry_run=False):
     """Given a directory path, import the YAML role files into the
     TemplateStore. When dry_run=True is passed, run through the roles but don't
     add any to the store.
@@ -78,6 +82,10 @@ def load_roles(directory, dry_run=False):
     :param directory: Directory name containing the roles
     :type  directory: str
 
+    :param seed_file: full path to the template seed that should be used for
+           plan master templates
+    :type  seed_file: str
+
     :return: Summary of the results as a tuple with the total count and then
         the names of the created and updated roles.
     :rtype:  tuple(list, list, list)
@@ -89,7 +97,7 @@ def load_roles(directory, dry_run=False):
 
     for name, role_path in roles:
 
-        contents = _read_role(role_path)
+        contents = _load_file(role_path)
         all_roles.append(name)
 
         if dry_run:
@@ -102,4 +110,15 @@ def load_roles(directory, dry_run=False):
         else:
             updated.append(name)
 
+    if seed_file is not None:
+        contents = _load_file(seed_file)
+        seed_created, role = _create_or_update(MASTER_SEED_NAME, contents,
+                                               store=MasterSeedStore())
+        all_roles.append(MASTER_SEED_NAME)
+
+        if seed_created:
+            created.append(MASTER_SEED_NAME)
+        else:
+            updated.append(MASTER_SEED_NAME)
+
     return all_roles, created, updated
